@@ -1,6 +1,9 @@
-DELETE IGNORE FROM mysql.plugin WHERE dl = 'ha_mroonga.so';
-
-INSTALL PLUGIN Mroonga SONAME 'ha_mroonga.so';
+SET @install_if_needs=IF(
+  EXISTS(SELECT * FROM mysql.plugin WHERE NAME = 'mroonga'),
+  'DO 1',
+  'INSTALL PLUGIN mroonga SONAME ''ha_mroonga.so''');
+PREPARE install_if_needs FROM @install_if_needs;
+EXECUTE install_if_needs;
 
 -- Deprecated. Use mroonga_last_insert_grn_id instead.
 DROP FUNCTION IF EXISTS last_insert_grn_id;
